diff graal/com.oracle.jvmci.hotspot/src/com/oracle/jvmci/hotspot/HotSpotJVMCIRuntime.java @ 21558:d563baeca9df

changed uses of Graal terminology to JVMCI (JBS:GRAAL-53)
author Doug Simon <doug.simon@oracle.com>
date Wed, 27 May 2015 13:43:27 +0200
parents 48c1ebd24120
children 4f63449b4422
line wrap: on
line diff
--- a/graal/com.oracle.jvmci.hotspot/src/com/oracle/jvmci/hotspot/HotSpotJVMCIRuntime.java	Wed May 27 13:32:18 2015 +0200
+++ b/graal/com.oracle.jvmci.hotspot/src/com/oracle/jvmci/hotspot/HotSpotJVMCIRuntime.java	Wed May 27 13:43:27 2015 +0200
@@ -182,11 +182,11 @@
     private final JVMCIBackend hostBackend;
 
     /**
      * Graal mirrors are stored as a {@link ClassValue} associated with the {@link Class} of the
      * type. This data structure stores both {@link HotSpotResolvedObjectType} and
      * {@link HotSpotResolvedPrimitiveType} types.
      */
-    private final ClassValue<ResolvedJavaType> graalMirrors = new ClassValue<ResolvedJavaType>() {
+    private final ClassValue<ResolvedJavaType> jvmciMirrors = new ClassValue<ResolvedJavaType>() {
         @Override
         protected ResolvedJavaType computeValue(Class<?> javaClass) {
             if (javaClass.isPrimitive()) {
@@ -207,7 +207,7 @@
             config = new HotSpotVMConfig(compilerToVm);
         }
 
-        if (Boolean.valueOf(System.getProperty("graal.printconfig"))) {
+        if (Boolean.valueOf(System.getProperty("jvmci.printconfig"))) {
             printConfig(config);
         }
 
@@ -230,7 +230,7 @@
     }
 
     public ResolvedJavaType fromClass(Class<?> javaClass) {
-        return graalMirrors.get(javaClass);
+        return jvmciMirrors.get(javaClass);
     }
 
     private static void printConfig(HotSpotVMConfig config) {
@@ -182,11 +182,11 @@
 
     /**
-     * Graal mirrors are stored as a {@link ClassValue} associated with the {@link Class} of the
+     * JVMCI mirrors are stored as a {@link ClassValue} associated with the {@link Class} of the
      * type. This data structure stores both {@link HotSpotResolvedObjectType} and
      * {@link HotSpotResolvedPrimitiveType} types.